pub enum RegionError {
NegativeSize(IVec3),
NoIntersection(Region, Region),
OutOfBounds(IVec3),
}Expand description
An set of error types that can be returned by a Region.
Variants
NegativeSize(IVec3)
An error that is thrown when attempting to create a region with a negative size.
NoIntersection(Region, Region)
An error that is thrown when attempting to create a region based on the intersection of two regions that do not interest at all.
OutOfBounds(IVec3)
An error that is thrown when attempting to get the index of a point that lies outside of the region bounds.