pub enum VoxelQueryError {
WorldNotFound(Entity),
ChunkNotFound(Entity, IVec3),
ChunkAlreadyExists(Entity, IVec3),
QueryError(QueryEntityError),
}Expand description
An error type that is thrown while handling voxel queries.
Variants
WorldNotFound(Entity)
Thrown when attempting to read from an invalid or non-existent world.
ChunkNotFound(Entity, IVec3)
Throw when there is no chunk located at the given chunk coordinates within a specific world.
ChunkAlreadyExists(Entity, IVec3)
Thrown when attempting to spawn a new chunk that already exists.
QueryError(QueryEntityError)
A standard Bevy query error.