VoxelChunkCommands

Struct VoxelChunkCommands 

pub struct VoxelChunkCommands<'world, 'state, 'cmd_ref> { /* private fields */ }
A Bevy command queue helper for working with Voxel chunk-based actions.

Implementations

Source

impl<'world, 'state, 'cmd_ref> VoxelChunkCommands<'world, 'state, 'cmd_ref>

pub fn despawn(self)

Despawns this chunk and all child entities attached to it, recursively.

This method will also update the internal chunk pointer cache of the voxel world to reflect the changes.

pub fn as_entity_commands(self) -> EntityCommands<'world, 'state, 'cmd_ref>

Gets the entity command queue for this voxel chunk object.

pub fn as_world_commands(self) -> VoxelWorldCommands<'world, 'state, 'cmd_ref>

Gets the voxel world command queue for the world that this chunk is in.

pub fn world_id(&self) -> Entity

Gets the id of the world that the chunk being handled is apart of.

pub fn id(&self) -> Entity

Gets the id of the chunk being handled.

pub fn chunk_coords(&self) -> IVec3

Gets the coordinates of the chunk being handled.