pub struct VoxelChunkCommands<'world, 'state, 'cmd_ref> { /* private fields */ }Expand description
A Bevy command queue helper for working with Voxel chunk-based actions.
Implementations
Sourceimpl<'world, 'state, 'cmd_ref> VoxelChunkCommands<'world, 'state, 'cmd_ref>
impl<'world, 'state, 'cmd_ref> VoxelChunkCommands<'world, 'state, 'cmd_ref>
Sourcepub fn despawn(self)
pub fn despawn(self)
Despawns this chunk and all child entities attached to it, recursively.
This method will also update the internal chunk pointer cache of the voxel world to reflect the changes.
Sourcepub fn as_entity_commands(self) -> EntityCommands<'world, 'state, 'cmd_ref>
pub fn as_entity_commands(self) -> EntityCommands<'world, 'state, 'cmd_ref>
Gets the entity command queue for this voxel chunk object.
Sourcepub fn as_world_commands(self) -> VoxelWorldCommands<'world, 'state, 'cmd_ref>
pub fn as_world_commands(self) -> VoxelWorldCommands<'world, 'state, 'cmd_ref>
Gets the voxel world command queue for the world that this chunk is in.
Sourcepub fn world_id(&self) -> Entity
pub fn world_id(&self) -> Entity
Gets the id of the world that the chunk being handled is apart of.
Sourcepub fn chunk_coords(&self) -> IVec3
pub fn chunk_coords(&self) -> IVec3
Gets the coordinates of the chunk being handled.