pub struct VoxelQuery<'w, 's, Q, F = ()>where
Q: WorldQuery + 'static,
F: ReadOnlyWorldQuery + 'static,{ /* private fields */ }Expand description
A system parameter designed for quickly querying and reading and writing to voxel worlds and voxel chunks.
Implementations
Sourceimpl<'w, 's, 'a, Q, F> VoxelQuery<'w, 's, Q, F>where
Q: WorldQuery + 'static,
F: ReadOnlyWorldQuery + 'static,
impl<'w, 's, 'a, Q, F> VoxelQuery<'w, 's, Q, F>where
Q: WorldQuery + 'static,
F: ReadOnlyWorldQuery + 'static,
Sourcepub fn iter(&'a self) -> impl Iterator<Item = ROQueryItem<'_, Q>> + '_
pub fn iter(&'a self) -> impl Iterator<Item = ROQueryItem<'_, Q>> + '_
Creates a readonly iterator over all chunks thaT match the given system query.
Sourcepub fn iter_mut(&'a mut self) -> impl Iterator<Item = QueryItem<'_, Q>> + '_
pub fn iter_mut(&'a mut self) -> impl Iterator<Item = QueryItem<'_, Q>> + '_
Creates a mutable iterator over all chunks thaT match the given system query.
Sourcepub fn get_world(
&'a self,
world_id: Entity,
) -> Result<VoxelWorldQuery<'w, 's, 'a, Q, F>, VoxelQueryError>
pub fn get_world( &'a self, world_id: Entity, ) -> Result<VoxelWorldQuery<'w, 's, 'a, Q, F>, VoxelQueryError>
Gets a readonly reference to the voxel world with the given world id. The world may or may not have any chunks in it that match the given system query.
Sourcepub fn get_world_mut(
&'a mut self,
world_id: Entity,
) -> Result<VoxelWorldQueryMut<'w, 's, 'a, Q, F>, VoxelQueryError>
pub fn get_world_mut( &'a mut self, world_id: Entity, ) -> Result<VoxelWorldQueryMut<'w, 's, 'a, Q, F>, VoxelQueryError>
Gets a mutable reference to the voxel world with the given world id. The world may or may not have any chunks in it that match the given system query.
Sourcepub fn world_iter(
&'a self,
) -> impl Iterator<Item = VoxelWorldQuery<'w, 's, 'a, Q, F>> + '_
pub fn world_iter( &'a self, ) -> impl Iterator<Item = VoxelWorldQuery<'w, 's, 'a, Q, F>> + '_
Gets a readonly iterator over all voxel worlds.
Note: This also includes worlds that do not contain any valid chunks within the system query.